@@ -67,6 +67,13 @@ topgenes_extract <- function(generes,  padj = 0.05, FC = 1.5, topNum = 30) {
     stop("padj, FC, and topNum must all be of class numeric.")
   }
   
+  if(is.null(generes[[1]]$avg_logFC)) {
+    message("Seurat V4 or later was used to identify cell-type markers, adding 'avg_logFC' column. It has the same data as avg_log2FC but is compatible with downstream functions in scMappR.")
+    for(z in 1:length(generes))
+      generes[[z]]$avg_logFC <- generes[[z]]$avg_log2FC
+  }
+  
+  
   topGenes <- list()
   for(i in 1:length(generes)) {
     #extract all genes that are above the cutoff
